==> temporal-sdk-1.26.0-sources.jar: io/temporal/internal/statemachines/ExecuteActivityParameters.java <==
/*
 * Copyright (C) 2022 Temporal Technologies, Inc. All Rights Reserved.
 *
 * Copyright (C) 2012-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Modifications copyright (C) 2017 Uber Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this material except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.temporal.internal.statemachines;

import io.temporal.activity.ActivityCancellationType;
import io.temporal.api.command.v1.ScheduleActivityTaskCommandAttributes;
import java.util.Objects;

public class ExecuteActivityParameters {

  private final ScheduleActivityTaskCommandAttributes.Builder attributes;
  private final ActivityCancellationType cancellationType;

  public ExecuteActivityParameters(
      ScheduleActivityTaskCommandAttributes.Builder attributes,
      ActivityCancellationType cancellationType) {
    this.attributes = Objects.requireNonNull(attributes);
    this.cancellationType = Objects.requireNonNull(cancellationType);
  }

  public ScheduleActivityTaskCommandAttributes.Builder getAttributes() {
    return attributes;
  }

  public ActivityCancellationType getCancellationType() {
    return cancellationType;
  }
}

==> temporal-sdk-1.28.4-sources.jar: io/temporal/internal/statemachines/ExecuteActivityParameters.java <==
/*
 * Copyright (C) 2022 Temporal Technologies, Inc. All Rights Reserved.
 *
 * Copyright (C) 2012-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Modifications copyright (C) 2017 Uber Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this material except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.temporal.internal.statemachines;

import io.temporal.activity.ActivityCancellationType;
import io.temporal.api.command.v1.ScheduleActivityTaskCommandAttributes;
import io.temporal.api.sdk.v1.UserMetadata;
import java.util.Objects;

public class ExecuteActivityParameters {

  private final ScheduleActivityTaskCommandAttributes.Builder attributes;
  private final ActivityCancellationType cancellationType;
  private final UserMetadata metadata;

  public ExecuteActivityParameters(
      ScheduleActivityTaskCommandAttributes.Builder attributes,
      ActivityCancellationType cancellationType,
      UserMetadata metadata) {
    this.attributes = Objects.requireNonNull(attributes);
    this.cancellationType = Objects.requireNonNull(cancellationType);
    this.metadata = metadata;
  }

  public ScheduleActivityTaskCommandAttributes.Builder getAttributes() {
    return attributes;
  }

  public ActivityCancellationType getCancellationType() {
    return cancellationType;
  }

  public UserMetadata getMetadata() {
    return metadata;
  }
}
